# noticeboard
Programs for a Raspberry Pi embedded in a corkboard for my to-do list etc

The visible software on this is based on Emacs' org-mode, showing my
"things to do" list.

The noticeboard also has a keyboard on a motorized sliding shelf, a
PIR detector, a couple of LED halogen-replacement bulbs, and a Picam.

The 12V PSU for the screen and the keyboard motor can be switched on
and off by a solid-state relay controlled from the Pi.

The program can take commands on its standard input, and is intended
to be commanded by Emacs.  However, it must have access to the GPIO
pins.
